Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(436)

Unified Diff: chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h
diff --git a/chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h b/chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h
index a60df564089d5181ebc19b36f0b6db0e78567d57..eacc5292abceefc84cb6a996c69484c463cca9d3 100644
--- a/chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h
+++ b/chrome/browser/chromeos/file_system_provider/fileapi/provider_async_file_util.h
@@ -7,7 +7,7 @@
#include "base/basictypes.h"
#include "base/callback.h"
-#include "webkit/browser/fileapi/async_file_util.h"
+#include "storage/browser/fileapi/async_file_util.h"
namespace chromeos {
namespace file_system_provider {
@@ -16,7 +16,7 @@ class FileSystemInterface;
namespace internal {
// The implementation of fileapi::AsyncFileUtil for provided file systems. It is
// created one per Chrome process. It is responsible for routing calls to the
// correct profile, and then to the correct profided file system.
//
@@ -26,77 +26,77 @@ namespace internal {
// See: https://code.google.com/p/gyp/issues/detail?id=384
//
// All of the methods should be called on the IO thread.
-class ProviderAsyncFileUtil : public fileapi::AsyncFileUtil {
+class ProviderAsyncFileUtil : public storage::AsyncFileUtil {
public:
ProviderAsyncFileUtil();
virtual ~ProviderAsyncFileUtil();
- // fileapi::AsyncFileUtil overrides.
+ // storage::AsyncFileUtil overrides.
virtual void CreateOrOpen(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
int file_flags,
const CreateOrOpenCallback& callback) OVERRIDE;
virtual void EnsureFileExists(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const EnsureFileExistsCallback& callback) OVERRIDE;
virtual void CreateDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
bool exclusive,
bool recursive,
const StatusCallback& callback) OVERRIDE;
virtual void GetFileInfo(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const GetFileInfoCallback& callback) OVERRIDE;
virtual void ReadDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const ReadDirectoryCallback& callback) OVERRIDE;
- virtual void Touch(scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ virtual void Touch(scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const base::Time& last_access_time,
const base::Time& last_modified_time,
const StatusCallback& callback) OVERRIDE;
- virtual void Truncate(scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ virtual void Truncate(scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
int64 length,
const StatusCallback& callback) OVERRIDE;
virtual void CopyFileLocal(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& src_url,
- const fileapi::FileSystemURL& dest_url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& src_url,
+ const storage::FileSystemURL& dest_url,
CopyOrMoveOption option,
const CopyFileProgressCallback& progress_callback,
const StatusCallback& callback) OVERRIDE;
virtual void MoveFileLocal(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& src_url,
- const fileapi::FileSystemURL& dest_url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& src_url,
+ const storage::FileSystemURL& dest_url,
CopyOrMoveOption option,
const StatusCallback& callback) OVERRIDE;
virtual void CopyInForeignFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
+ scoped_ptr<storage::FileSystemOperationContext> context,
const base::FilePath& src_file_path,
- const fileapi::FileSystemURL& dest_url,
+ const storage::FileSystemURL& dest_url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteRecursively(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void CreateSnapshotFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const CreateSnapshotFileCallback& callback) OVERRIDE;
private:
@@ -16,7 +16,7 @@ class FileSystemInterface;
namespace internal {
-// The implementation of fileapi::AsyncFileUtil for provided file systems. It is
+// The implementation of storage::AsyncFileUtil for provided file systems. It is
// created one per Chrome process. It is responsible for routing calls to the
// correct profile, and then to the correct profided file system.

Powered by Google App Engine
This is Rietveld 408576698